@@ -7,7 +7,8 @@
 #
 # Copyright (C) 2000 SF Interactive, Inc.  All rights reserved.
 #
-# Author:  Jacob Davies <jacob@sfinteractive.com> <jacob@well.com>
+# Maintainer: Matisse Enzer <matisse@matisse.net> (30 May 2002)
+# Author:  Jacob Davies <jacob@well.com>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -30,7 +31,8 @@ use strict;
 use 5.004;
 use English;
 use vars qw( $VERSION );
-( $VERSION ) = '$Revision: 1.4 $' =~ /([\d.]+)/;
+# '$Revision: 1.13 $' =~ /([\d.]+)/;
+$VERSION = '1.81';
 use IO::File;
 require Exporter;
 use vars qw ( @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
@@ -182,7 +184,7 @@ sub _urlesc($)
 
 =head1 VERSION
 
-	$Revision: 1.4 $
+	1.7
 
 =head1 SYNOPSIS
 
@@ -296,6 +298,9 @@ or with quoted parameters like:
 
 	<#TAG NAME="Value, including spaces etc.">
 
+Tags may be embedded in other tags (as of version 1.5), e.g.
+    <#USERINFO DISPLAY="<#FAVORITE_COLOR>">
+
 The tag name is the first part after the opening <# of the whole tag.  It must
 be a simple identifier -- I recommend sticking to the character set [A-Z_] for
 this.  The following parameters are optional and only used if the tag-action is
@@ -1125,7 +1130,7 @@ sub parse
 	}
 
 	# Loop until we have replaced all the tags.
-        while ( $string =~ /<#([^>]*)>/g ) {
+        while ( $string =~ /<#([^<>]*)>/g ) {
                 my $contents = $1;
 		my $q_contents = quotemeta $contents;
 		my $o_contents = $contents; # preserve in case we're ignoring.
@@ -1133,16 +1138,17 @@ sub parse
 		$contents =~ s/^\s+//;
 		$contents =~ s/\s+$//;
 		# Remove whitespace in quoted values.
-		$contents =~ s|"([^="]*)"|
+		$contents =~ s|"([^"]*)"|
 			my $value = $1;
 			$value =~ s/ /\&#032;/g;
 			$value =~ s/\t/\&#009;/g;
 			$value =~ s/\n/\&#010;/g;
 			$value =~ s/\r/\&#013;/g;
+			$value =~ s/=/\&#061;/g;
 			$value;
 		|egm;
 		# Remove whitespace between parameters/equals-signs/values.
-                $contents =~ s/\s*=\s*/=/g;
+                $contents =~ s/\s+=\s+/=/g;
 
                 my %params = ();
 		# Chop up the contents into the tag name and the params.
@@ -1226,7 +1232,10 @@ sub parse
 		}
 
 		# Substitute in the string.
-                $string =~ s/<#$q_contents>/$rep/;
+                {
+                    no warnings; # Avoid stoopid warnings in case $rep is empty
+                    $string =~ s/<#$q_contents>/$rep/;
+                }
         }
 
 	if ( $self->{ UNKNOWN_ACTION } eq 'IGNORE' ) {
@@ -1392,9 +1401,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 Jacob Davies
 
-	<jacob@sfinteractive.com>
 	<jacob@well.com>
 
+=head1 MAINTAINER
+
+Matisse Enzer
+
+	<matisse@matisse.net>
+
 =head1 SEE ALSO
 
 The README file supplied with the distribution, and the example/ subdirectory
